package com.hikcreate.edl.pub.web.mobile.api.controller;

import cn.hutool.core.date.DateTime;
import com.hikcreate.edl.pub.web.mobile.domain.IBindService;
import com.hikcreate.edl.pub.web.mobile.infra.core.Result;
import com.hikcreate.edl.pub.web.mobile.infra.core.enums.ResultCode;
import com.hikcreate.edl.pub.web.mobile.infra.core.page.PageResult;
import com.hikcreate.edl.pub.web.mobile.infra.data.mapper.BindInfoMapper;
import com.hikcreate.edl.pub.web.mobile.infra.model.BindInfo;
import com.hikcreate.edl.pub.web.mobile.infra.model.BindInfoQuery;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;


/**
 * description:绑定信息的controller
 *
 * @author: xieshixiang
 * @time：2020/6/18 15:59
 **/
@RestController
@RequestMapping("/vehicle")
@Slf4j
public class BindInfoControlller extends BaseController {

    @Autowired
    IBindService service;
    @Resource
    BindInfoMapper mapper;


    @PostMapping("bind")
    public Result bindInfo(@RequestBody BindInfo info) {
        if (info == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "参数不能为空");
        }
        return service.bind(info);
    }


    @PostMapping("unbind")
    public Result unbindInfo(@RequestBody BindInfo info) {
        if (info == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "参数不能为空");
        }
        info.setEditorTime(new DateTime());
        return mapper.updateById(info) > 0 ? Result.successResult() : Result.errorResult();
    }

    @PostMapping("query")
    public Result bindInfoQery(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "参数不能为空");
        }
        return Result.successResult(mapper.selectByQuery(query));
    }


    @GetMapping("authentication")
    public Result authority(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "参数不能为空");
        }
        PageResult<BindInfo> bindInfos = mapper.selectByQuery(query);
        return bindInfos.getAllCount() > 0 ? Result.successResult(bindInfos) :
                Result.errorResult(ResultCode.HASH_NO_PRIVILEGE);
    }


}
